import { defineComponent, h } from 'vue';
export const File = defineComponent({
    name: 'ScFileField',
    inheritAttrs: false,
    props: {
        /** The file field data. */
        field: {
            type: Object,
            default() {
                return {};
            },
            required: true,
        },
    },
    render() {
        const { field } = this.$props;
        /*
        File fields cannot be managed via the EE. We never output "editable."
      */
        if (!field || (!field.value && !field.src)) {
            return null;
        }
        // handle link directly on field for forgetful devs
        const file = field.src ? field : field.value;
        if (!file) {
            return null;
        }
        if (this.$slots && this.$slots.default) {
            return this.$slots.default(file);
        }
        const linkText = file.title || file.displayName;
        // this.$data should be passed along to the
        // `createElement` function in order to retain attributes and events
        // https://v3.vuejs.org/guide/render-function.html#render-functions
        const data = Object.assign(Object.assign(Object.assign({}, this.$data), this.$attrs), { href: file.src });
        return h('a', data, linkText);
    },
});
